@@ -149,7 +149,7 @@ JAGS_fit <- function(model_syntax, data = NULL, prior_list = NULL, formula_list
   # parallel vs. not
   if(parallel){
     cl <- parallel::makePSOCKcluster(cores)
-    on.exit(parallel::stopCluster(cl))
+    on.exit(try(parallel::stopCluster(cl)))
     for(i in seq_along(required_packages)){
       parallel::clusterCall(cl, function(x) requireNamespace(required_packages[i]))
     }
@@ -198,9 +198,9 @@ JAGS_fit <- function(model_syntax, data = NULL, prior_list = NULL, formula_list
   if(inherits(fit, "error") & !silent)
     warning(paste0("The model estimation failed with the following error: ", fit$message), immediate. = TRUE)
 
-  if(autofit & !inherits(fit, "error")){
+  if(autofit && !inherits(fit, "error")){
 
-    converged <- JAGS_check_convergence(fit, prior_list, autofit_control[["max_Rhat"]], autofit_control[["min_ESS"]], autofit_control[["max_error"]], autofit_control[["max_SD_error"]])
+    converged <- JAGS_check_convergence(fit, prior_list, autofit_control[["max_Rhat"]], autofit_control[["min_ESS"]], autofit_control[["max_error"]], autofit_control[["max_SD_error"]], fail_fast = TRUE)
 
     while(!converged){
 
@@ -222,13 +222,10 @@ JAGS_fit <- function(model_syntax, data = NULL, prior_list = NULL, formula_list
         break
       }
 
-      converged <- JAGS_check_convergence(fit, prior_list, autofit_control[["max_Rhat"]], autofit_control[["min_ESS"]], autofit_control[["max_error"]], autofit_control[["max_SD_error"]])
-    }
-  }
+      fit <- runjags::add.summary(fit)
 
-  # stop cluster manually
-  if(parallel){
-    parallel::stopCluster(cl)
+      converged <- JAGS_check_convergence(fit, prior_list, autofit_control[["max_Rhat"]], autofit_control[["min_ESS"]], autofit_control[["max_error"]], autofit_control[["max_SD_error"]], fail_fast = TRUE)
+    }
   }
 
   # add information to the fitted object
@@ -260,7 +257,7 @@ JAGS_extend <- function(fit, autofit_control = list(max_Rhat = 1.05, min_ESS = 5
       cores <- length(fit[["mcmc"]])
     }
     cl <- parallel::makePSOCKcluster(cores)
-    on.exit(parallel::stopCluster(cl))
+    on.exit(try(parallel::stopCluster(cl)))
     for(i in seq_along(required_packages)){
       parallel::clusterCall(cl, function(x) requireNamespace(required_packages[i]))
     }
@@ -295,9 +292,10 @@ JAGS_extend <- function(fit, autofit_control = list(max_Rhat = 1.05, min_ESS = 5
   }
 
   start_time <- Sys.time()
+  itteration <- 0
   converged  <- FALSE
 
-  while(!converged){
+  while(!converged & itteration < autofit_control[["restarts"]]){
 
     if(!is.null(autofit_control[["max_time"]]) && difftime(Sys.time(), start_time, units = autofit_control[["max_time"]][["unit"]]) > autofit_control[["max_time"]][["time"]]){
       if(!silent){
@@ -317,12 +315,13 @@ JAGS_extend <- function(fit, autofit_control = list(max_Rhat = 1.05, min_ESS = 5
       break
     }
 
-    converged <- JAGS_check_convergence(fit, prior_list, autofit_control[["max_Rhat"]], autofit_control[["min_ESS"]], autofit_control[["max_error"]], autofit_control[["max_SD_error"]])
-  }
+    converged <- JAGS_check_convergence(fit, prior_list, autofit_control[["max_Rhat"]], autofit_control[["min_ESS"]], autofit_control[["max_error"]], autofit_control[["max_SD_error"]], fail_fast = TRUE)
 
-  # stop cluster manually
-  if(parallel){
-    parallel::stopCluster(cl)
+    # update the refit call
+    if(!converged){
+      itteration <- itteration + 1
+      refit_call$runjags.object <- fit
+    }
   }
 
   # add information to the fitted object
@@ -349,6 +348,9 @@ JAGS_extend <- function(fit, autofit_control = list(max_Rhat = 1.05, min_ESS = 5
 #' @param max_error maximum MCMC error. Defaults to \code{1.01}.
 #' @param max_SD_error maximum MCMC error as the proportion of standard
 #'   deviation of the parameters. Defaults to \code{0.05}.
+#' @param add_parameters vector of additional parameter names that should be used
+#' (only allows removing last, fixed, omega element if omega is tracked manually).
+#' @param fail_fast whether the function should stop after the first failed convergence check.
 #'
 #' @examples \dontrun{
 #' # simulate data
@@ -380,62 +382,118 @@ JAGS_extend <- function(fit, autofit_control = list(max_Rhat = 1.05, min_ESS = 5
 #'
 #' @seealso [JAGS_fit()]
 #' @export
-JAGS_check_convergence <- function(fit, prior_list, max_Rhat = 1.05, min_ESS = 500, max_error = 0.01, max_SD_error = 0.05){
+JAGS_check_convergence <- function(fit, prior_list, max_Rhat = 1.05, min_ESS = 500, max_error = 0.01, max_SD_error = 0.05, add_parameters = NULL, fail_fast = FALSE){
 
   # check input
   if(!inherits(fit, "runjags"))
     stop("'fit' must be a runjags fit")
-  check_list(prior_list, "prior_list")
-  if(any(!sapply(prior_list, is.prior)))
+  check_list(prior_list, "prior_list", allow_NULL = TRUE)
+  if(!is.null(prior_list) && any(!sapply(prior_list, is.prior)))
     stop("'prior_list' must be a list of priors.")
   check_real(max_Rhat,     "max_Rhat",     lower = 1, allow_NULL = TRUE)
   check_real(min_ESS,      "min_ESS",      lower = 0, allow_NULL = TRUE)
   check_real(max_error,    "max_error",    lower = 0, allow_NULL = TRUE)
   check_real(max_SD_error, "max_SD_error", lower = 0, upper = 1, allow_NULL = TRUE)
+  check_char(add_parameters, "add_parameters", check_length = 0, allow_NULL = TRUE)
 
-  fails         <- NULL
-  invisible(utils::capture.output(temp_summary <- suppressWarnings(summary(fit, silent.jags = TRUE))))
+  # extract samples and parameter information
+  mcmc_samples    <- coda::as.mcmc.list(fit)
+  parameter_names <- colnames(mcmc_samples[[1]])
+  parameters_keep <- rep(TRUE, length(parameter_names))
 
   # remove auxiliary and support parameters from the summary
   for(i in seq_along(prior_list)){
     if(is.prior.weightfunction(prior_list[[i]])){
       if(prior_list[[i]][["distribution"]] %in% c("one.sided", "two.sided")){
-        temp_summary <- temp_summary[!grepl("eta", rownames(temp_summary)),,drop=FALSE]
+        parameters_keep[grepl("eta", parameter_names)] <- FALSE
       }
-      temp_summary <- temp_summary[-max(grep("omega", rownames(temp_summary))),,drop=FALSE]
+      parameter_names[max(grep("omega", parameter_names))] <- FALSE
+    }else if(is.prior.mixture(prior_list[[i]]) && any(sapply(prior_list[[i]], is.prior.weightfunction))){
+      parameters_keep[max(grep("omega", parameter_names))] <- FALSE
     }else if(is.prior.point(prior_list[[i]])){
-      temp_summary <- temp_summary[rownames(temp_summary) != names(prior_list)[i],,drop=FALSE]
+      parameters_keep[parameter_names == names(prior_list)[i]] <- FALSE
     }else if(is.prior.simple(prior_list[[i]]) && prior_list[[i]][["distribution"]] == "invgamma"){
-      temp_summary <- temp_summary[rownames(temp_summary) != paste0("inv_",names(prior_list)[i]),,drop=FALSE]
+      parameters_keep[parameter_names == paste0("inv_",names(prior_list)[i])] <- FALSE
+    }else if(is.prior.mixture(prior_list[[i]]) && length(prior_list[[i]]) == 1 && is.prior.point(prior_list[[i]][[1]])){
+      parameters_keep[parameter_names == names(prior_list)[i]] <- FALSE
     }
   }
 
-  # check the convergence
+  # remove indicators/inclusions
+  parameters_keep[grepl("_indicator", parameter_names)] <- FALSE
+  parameters_keep[grepl("_inclusion", parameter_names)] <- FALSE
+
+  if(all(!parameters_keep)){
+    return(TRUE)
+  }
+
+  # remove parameters that are not monitored
+  for(i in seq_along(mcmc_samples)){
+    mcmc_samples[[i]] <- mcmc_samples[[i]][,parameters_keep,drop=FALSE]
+  }
+
+  ### check the convergence
+  fails <- NULL
+
+  # assess R-hat
   if(!is.null(max_Rhat)){
-    temp_Rhat <- max(ifelse(is.na(temp_summary[, "psrf"]), 1, temp_summary[, "psrf"]))
-    if(temp_Rhat > max_Rhat){
-      fails <- c(fails, paste0("R-hat ", round(temp_Rhat, 3), " is larger than the set target (", max_Rhat, ")."))
+    if(length(fit$mcmc) == 1){
+      warning("Only one chain was run. R-hat cannot be computed.", immediate. = TRUE)
+    }else{
+      temp_Rhat <- coda::gelman.diag(mcmc_samples, multivariate = FALSE, autoburnin = FALSE)$psrf
+      temp_Rhat[is.na(temp_Rhat)] <- 1
+      temp_Rhat <- max(temp_Rhat)
+      if(temp_Rhat > max_Rhat){
+        fails <- c(fails, paste0("R-hat ", round(temp_Rhat, 3), " is larger than the set target (", max_Rhat, ")."))
+        if(fail_fast){
+          return(FALSE)
+        }
+      }
     }
   }
 
   if(!is.null(min_ESS)){
-    temp_ESS <- min(ifelse(is.na(temp_summary[, "SSeff"]), Inf, temp_summary[, "SSeff"]))
+    temp_ESS <- coda::effectiveSize(mcmc_samples)
+    temp_ESS[is.nan(temp_ESS) | temp_ESS == 0] <- Inf
+    temp_ESS <- min(temp_ESS)
     if(temp_ESS < min_ESS){
       fails <- c(fails, paste0("ESS ", round(temp_ESS), " is lower than the set target (", min_ESS, ")."))
+      if(fail_fast){
+        return(FALSE)
+      }
     }
   }
 
+  # compute the MCMC error and & SD error
+  if(!(is.null(max_error) && is.null(max_SD_error))){
+    temp_summary <- summary(mcmc_samples, quantiles = NULL)$statistics
+    if(is.null(dim(temp_summary))){
+      temp_summary <- t(temp_summary)
+    }
+  }
+
+
   if(!is.null(max_error)){
-    temp_error    <- max(ifelse(is.na(temp_summary[, "MCerr"]), 0, temp_summary[, "MCerr"]))
+    temp_error    <- temp_summary[,"Time-series SE"]
+    temp_error[is.na(temp_error)] <- 0
+    temp_error    <- max(temp_error)
     if(temp_error > max_error){
       fails <- c(fails, paste0("MCMC error ", round(temp_error, 5), " is larger than the set target (", max_error, ")."))
+      if(fail_fast){
+        return(FALSE)
+      }
     }
   }
 
   if(!is.null(max_SD_error)){
-    temp_error_SD <- max(ifelse(is.na(temp_summary[, "MC%ofSD"]),   0, temp_summary[, "MC%ofSD"]))
-    if(temp_error_SD/100 > max_SD_error){
-      fails <- c(fails, paste0("MCMC SD error ", round(temp_error_SD/100, 4), " is larger than the set target (", max_SD_error, ")."))
+    temp_error_SD <- temp_summary[,"Time-series SE"] / temp_summary[,"SD"]
+    temp_error_SD[is.na(temp_error_SD)] <- 0
+    temp_error_SD <- max(temp_error_SD)
+    if(temp_error_SD > max_SD_error){
+      fails <- c(fails, paste0("MCMC SD error ", round(temp_error_SD, 3), " is larger than the set target (", max_SD_error, ")."))
+      if(fail_fast){
+        return(FALSE)
+      }
     }
   }
 
@@ -468,6 +526,8 @@ JAGS_add_priors           <- function(syntax, prior_list){
     stop("'prior_list' must be a list of priors.")
   .check_JAGS_syntax(syntax)
 
+  # create an empty attribute holder if any data need to be passed with the syntax
+  syntax_attributes <- NULL
 
   # identify parts of the syntax
   opening_bracket <- regexpr("{", syntax, fixed = TRUE)[1]
@@ -476,9 +536,15 @@ JAGS_add_priors           <- function(syntax, prior_list){
 
   # create the priors relevant syntax
   syntax_priors <- .JAGS_add_priors.fun(prior_list)
+  if(!is.null(attr(syntax_priors, "auxiliary_data"))){
+    syntax_attributes <- attr(syntax_priors, "auxiliary_data")
+  }
 
   # merge everything back together
   syntax <- paste0(syntax_start, "\n", syntax_priors, "\n", syntax_end)
+  if(!is.null(attr(syntax_priors, "auxiliary_data"))){
+    attr(syntax, "auxiliary_data") <- syntax_attributes
+  }
 
   return(syntax)
 }
@@ -486,6 +552,7 @@ JAGS_add_priors           <- function(syntax, prior_list){
 .JAGS_add_priors.fun       <- function(prior_list){
 
   syntax_priors <- ""
+  syntax_attributes <- NULL
 
   for(i in seq_along(prior_list)){
 
@@ -501,6 +568,14 @@ JAGS_add_priors           <- function(syntax, prior_list){
 
       syntax_priors <- paste(syntax_priors, .JAGS_prior.spike_and_slab(prior_list[[i]], names(prior_list)[i]))
 
+    }else if(is.prior.mixture(prior_list[[i]])){
+
+      syntax_mixture <- .JAGS_prior.mixture(prior_list[[i]], names(prior_list)[i])
+      syntax_priors  <- paste(syntax_priors, syntax_mixture)
+      if(!is.null(attr(syntax_mixture, "auxiliary_data"))){
+        syntax_attributes <- attr(syntax_mixture, "auxiliary_data")
+      }
+
     }else if(is.prior.factor(prior_list[[i]])){
 
       syntax_priors <- paste(syntax_priors, .JAGS_prior.factor(prior_list[[i]], names(prior_list)[i]))
@@ -516,6 +591,10 @@ JAGS_add_priors           <- function(syntax, prior_list){
     }
   }
 
+  if(length(syntax_attributes) > 0){
+    attr(syntax_priors, "auxiliary_data") <- syntax_attributes
+  }
+
   return(syntax_priors)
 }
 .JAGS_prior.simple         <- function(prior, parameter_name){
@@ -730,12 +809,6 @@ JAGS_add_priors           <- function(syntax, prior_list){
     stop("improper prior provided")
   check_char(parameter_name, "parameter_name")
 
-  if(is.prior.PET(prior[["variable"]]) | is.prior.PEESE(prior[["variable"]]) | is.prior.weightfunction(prior[["variable"]]))
-    stop("Spike and slab functionality is not implemented for publication bias prior distributions.")
-  if(is.prior.spike_and_slab(prior[["variable"]]))
-     stop("Spike and slab prior distribution cannot be nested inside of a spike and slab prior distribution.")
-
-
   prior_variable_list  <- prior["variable"]
   prior_inclusion_list <- prior["inclusion"]
   names(prior_variable_list)  <- paste0(parameter_name, "_variable")
@@ -750,7 +823,186 @@ JAGS_add_priors           <- function(syntax, prior_list){
 
   return(syntax)
 }
+.JAGS_prior.mixture        <- function(prior_list, parameter_name){
 
+  .check_prior_list(prior_list)
+  if(!is.prior.mixture(prior_list))
+    stop("improper prior provided")
+  check_char(parameter_name, "parameter_name")
+
+  if(inherits(prior_list, "prior.bias_mixture")){
+
+    # dispatch between publication bias prior mixture and a standard prior mixture
+    is_PET            <- sapply(prior_list, is.prior.PET)
+    is_PEESE          <- sapply(prior_list, is.prior.PEESE)
+    is_weightfunction <- sapply(prior_list, is.prior.weightfunction)
+    is_none           <- sapply(prior_list, is.prior.none)
+
+    prior_weights <- attr(prior_list, "prior_weights")
+    syntax <- paste0(" bias_indicator ~ dcat(c(", paste0(prior_weights, collapse = ", "), "))\n")
+
+    # if any prior is bias related, the whole component must be dispatching publication bias
+    if(any(!(is_PET | is_PEESE | is_weightfunction | is_none)))
+      stop("Mixture of publication bias and standard priors is not supported.")
+
+    if(any(is_PET)){
+      if(sum(is_PET) > 1) stop("Only one PET style publication bias adjustment is allowed.")
+
+      named_prior_PET <- prior_list[[which(is_PET)]]
+      class(named_prior_PET) <- class(named_prior_PET)[!class(named_prior_PET) %in% "prior.PET"]
+      named_prior_PET <- list("PET_1" = named_prior_PET)
+
+      syntax <- paste0(
+        syntax,
+        .JAGS_add_priors.fun(named_prior_PET),
+        " PET = PET_1 * (bias_indicator == ", which(is_PET), ")\n"
+      )
+    }
+    if(any(is_PEESE)){
+      if(sum(is_PEESE) > 1) stop("Only one PEESE style publication bias adjustment is allowed.")
+
+      named_prior_PEESE <- prior_list[[which(is_PEESE)]]
+      class(named_prior_PEESE) <- class(named_prior_PEESE)[!class(named_prior_PEESE) %in% "prior.PEESE"]
+      named_prior_PEESE <- list("PEESE_1" = named_prior_PEESE)
+
+      syntax <- paste0(
+        syntax,
+        .JAGS_add_priors.fun(named_prior_PEESE),
+        " PEESE = PEESE_1 * (bias_indicator == ", which(is_PEESE), ")\n"
+      )
+    }
+    if(any(is_weightfunction)){
+      # we cannot simulate weights from the mixture distribution directly because
+      # JAGS does not allow complex support for the cumulative simplex parameter
+      # (we could make it on the non-cumulative simplex but it does not give more advantage)
+
+      # create a vector of the alpha parameters
+      alpha <- lapply(prior_list[is_weightfunction], function(x){
+        if(grepl("fixed", x[["distribution"]])){
+          return(x$parameters[["omega"]])
+        }else{
+          return(x$parameters[["alpha"]])
+        }
+      })
+
+      # dispatch the prior distribution on weight parameters
+      syntax <- paste0(
+        syntax,
+        " for(i in 1:", max(lengths(alpha)), "){\n",
+        "   eta[i] ~ dgamma(eta_shape[i, bias_indicator], 1)\n",
+        " }\n"
+      )
+
+      # transform etas into weights (eta2omega JAGS function is in the RoBMA package)
+      syntax <- paste0(syntax, " omega = eta2omega(eta, omega_index[,bias_indicator], eta_index[,bias_indicator], eta_index_max[bias_indicator])\n")
+
+      # add the necessary auxiliary data: omega_index, eta_index, eta_index_max, eta_shape
+      # create the weightfunction mapping for weights
+      omega_index_weighfunction <- weightfunctions_mapping(prior_list[is_weightfunction], one_sided = TRUE)
+      omega_index_weighfunction <- lapply(omega_index_weighfunction, rev)
+      omega_index_weighfunction <- do.call(rbind, omega_index_weighfunction)
+      omega_index <- matrix(0, ncol = ncol(omega_index_weighfunction), length(prior_list))
+      omega_index[is_weightfunction,] <- omega_index_weighfunction
+
+      # in case of fixed weight functions, the omega_index direly corresponds to the fixed weights
+      for(i in seq_along(prior_list)){
+        if(is.prior.weightfunction(prior_list[[i]])){
+          if(grepl("fixed", prior_list[[i]]$distribution)){
+            omega_index[i,] <- prior_list[[i]]$parameters[["omega"]][omega_index[i,]]
+          }
+        }
+      }
+
+      # create the eta to omega mapping
+      # eta_index_max helps dispatching within the eta2omega function
+      # 0  = non-weightfunction, all weights are set to 0
+      # >1 = indicates how many alpha parameters are needed to construct the weightfunction based on the eta_index
+      # -1 = indicates fixed weightfunction, omega index already encoded all weights
+      eta_index     <- matrix(0, nrow = length(prior_list), ncol = max(lengths(alpha)))
+      eta_index_max <- rep(0, length(prior_list))
+      for(i in seq_along(prior_list)){
+        if(is.prior.weightfunction(prior_list[[i]])){
+          if(grepl("fixed", prior_list[[i]]$distribution)){
+            eta_index_max[i] <- -1
+            eta_index[i,]    <- -1
+          }else{
+            temp_index       <- unique(omega_index[i,])
+            eta_index[i,1:length(temp_index)] <- sort(temp_index)
+            eta_index_max[i] <- length(temp_index)
+          }
+        }else{
+          eta_index_max[i] <- 0
+        }
+      }
+
+      # create priors for eta (set alpha to 1 for non-weightfunctions to keep the sampling in the expected area)
+      eta_shape <- matrix(1, nrow = length(prior_list), ncol = max(lengths(alpha)))
+      for(i in seq_along(prior_list)){
+        if(is.prior.weightfunction(prior_list[[i]])){
+          if(!grepl("fixed", prior_list[[i]]$distribution)){
+            temp_shape <- prior_list[[i]]$parameters[["alpha"]]
+            eta_shape[i,1:length(temp_shape)] <- temp_shape
+          }
+        }
+      }
+
+      # paste the matricies directly into JAGS code (simplifies data handling)
+      syntax <- paste0(
+        syntax,
+        .add_JAGS_matrix("omega_index",   t(omega_index)),
+        .add_JAGS_matrix("eta_index",     t(eta_index)),
+        .add_JAGS_vector("eta_index_max", eta_index_max),
+        .add_JAGS_matrix("eta_shape",     t(eta_shape))
+      )
+    }
+
+  }else{
+
+    prior_weights    <- attr(prior_list, "prior_weights")
+    prior_components <- as.list(prior_list)
+    class(prior_components) <- "list"
+    names(prior_components) <- paste0(parameter_name, "_component_", seq_along(prior_components))
+
+    syntax <- paste0(
+      " ", parameter_name, "_indicator ~ dcat(c(", paste0(prior_weights, collapse = ", "), "))\n",
+      sapply(.JAGS_add_priors.fun(prior_components), paste, collapse = "\n"),
+      " ", parameter_name, " = ",  paste0(names(prior_components), " * ", paste0("(", parameter_name, "_indicator == ", seq_along(prior_components), ")"), collapse = " + "), "\n"
+    )
+  }
+
+  return(syntax)
+}
+
+
+.add_JAGS_vector   <- function(name, vector){
+
+  if(!is.vector(vector))
+    stop("vector must be a vector")
+  check_char(name, "name")
+
+  syntax <- paste0(" ", name, " = c(", paste0(vector, collapse = ", "), ")\n")
+
+  return(syntax)
+}
+.add_JAGS_matrix   <- function(name, matrix){
+
+  if(!is.matrix(matrix))
+    stop("matrix must be a matrix")
+  check_char(name, "name")
+
+  syntax <- ""
+
+  # this unfortunatelly cannot be defined on row/column basis
+  # I tried simplifying this before but only possible initialization is elementwise
+  for(i in 1:nrow(matrix)){
+   syntax <- paste0(
+     syntax, " ",
+     paste0(name,"[", i, ",", seq_len(ncol(matrix)), "] = ", matrix[i,], collapse = "; "), "\n"
+   )
+  }
+
+  return(syntax)
+}
 .check_JAGS_syntax <- function(syntax){
 
   check_char(syntax, "syntax", allow_NULL = TRUE)
@@ -837,6 +1089,10 @@ JAGS_get_inits            <- function(prior_list, chains, seed){
 
       temp_inits <- c(temp_inits, .JAGS_init.spike_and_slab(prior_list[[i]], names(prior_list)[i]))
 
+    }else if(is.prior.mixture(prior_list[[i]])){
+
+      temp_inits <- c(temp_inits, .JAGS_init.mixture(prior_list[[i]], names(prior_list)[i]))
+
     }else if(is.prior.factor(prior_list[[i]])){
 
       temp_inits <- c(temp_inits, .JAGS_init.factor(prior_list[[i]], names(prior_list)[i]))
@@ -993,6 +1249,74 @@ JAGS_get_inits            <- function(prior_list, chains, seed){
 
   return(init)
 }
+.JAGS_init.mixture         <- function(prior_list, parameter_name){
+
+  .check_prior_list(prior_list)
+  if(!is.prior.mixture(prior_list))
+    stop("improper prior provided")
+  check_char(parameter_name, "parameter_name")
+
+  if(inherits(prior_list, "prior.bias_mixture")){
+
+    # dispatch between publication bias prior mixture and a standard prior mixture
+    is_PET            <- sapply(prior_list, is.prior.PET)
+    is_PEESE          <- sapply(prior_list, is.prior.PEESE)
+    is_weightfunction <- sapply(prior_list, is.prior.weightfunction)
+    is_none           <- sapply(prior_list, is.prior.none)
+
+    init <- list()
+
+    # if any prior is bias related, the whole component must be dispatching publication bias
+    if(any(!(is_PET | is_PEESE | is_weightfunction | is_none)))
+      stop("Mixture of publication bias and standard priors is not supported.")
+
+    if(any(is_PET)){
+      if(sum(is_PET) > 1) stop("Only one PET style publication bias adjustment is allowed.")
+
+      named_prior_PET <- prior_list[[which(is_PET)]]
+      class(named_prior_PET) <- class(named_prior_PET)[!class(named_prior_PET) %in% "prior.PET"]
+      named_prior_PET <- list("PET_1" = named_prior_PET)
+
+      init <- c(init, .JAGS_get_inits.fun(named_prior_PET))
+    }
+    if(any(is_PEESE)){
+      if(sum(is_PEESE) > 1) stop("Only one PEESE style publication bias adjustment is allowed.")
+
+      named_prior_PEESE <- prior_list[[which(is_PEESE)]]
+      class(named_prior_PEESE) <- class(named_prior_PEESE)[!class(named_prior_PEESE) %in% "prior.PEESE"]
+      named_prior_PEESE <- list("PEESE_1" = named_prior_PEESE)
+
+      init <- c(init, .JAGS_get_inits.fun(named_prior_PEESE))
+    }
+    if(any(is_weightfunction)){
+
+      # find prior with the most alpha parameters and simulate initial values from it
+      alpha <- sapply(prior_list[is_weightfunction], function(x){
+        if(grepl("fixed", x[["distribution"]])){
+          return(length(x$parameters[["omega"]]))
+        }else{
+          return(length(x$parameters[["alpha"]]))
+        }
+      })
+
+      init <- c(init, .JAGS_get_inits.fun(prior_list[is_weightfunction][which.max(alpha)]))
+    }
+
+    init[["bias_indicator"]] <- rng(prior_list, 1, sample_components = TRUE)
+
+  }else{
+
+    prior_components <- as.list(prior_list)
+    class(prior_components) <- "list"
+    names(prior_components) <- paste0(parameter_name, "_component_", seq_along(prior_components))
+
+    init <- .JAGS_get_inits.fun(prior_components)
+    init[[paste0(parameter_name, "_indicator")]] <- rng(prior_list, 1, sample_components = TRUE)
+
+  }
+
+  return(init)
+}
 
 
 #' @title Create list of monitored parameters for 'JAGS' model
@@ -1034,6 +1358,10 @@ JAGS_to_monitor             <- function(prior_list){
 
       monitor <- c(monitor, .JAGS_monitor.spike_and_slab(prior_list[[i]], names(prior_list)[i]))
 
+    }else if(is.prior.mixture(prior_list[[i]])){
+
+      monitor <- c(monitor, .JAGS_monitor.mixture(prior_list[[i]], names(prior_list)[i]))
+
     }else if(is.prior.factor(prior_list[[i]])){
 
       monitor <- c(monitor, .JAGS_monitor.factor(prior_list[[i]], names(prior_list)[i]))
@@ -1122,14 +1450,57 @@ JAGS_to_monitor             <- function(prior_list){
   names(prior_inclusion) <- paste0(parameter_name, "_inclusion")
 
   monitor <- c(
-    parameter_name,
-    JAGS_to_monitor(prior_variable),
+    paste0(parameter_name, "_indicator"),
     JAGS_to_monitor(prior_inclusion),
-    paste0(parameter_name, "_indicator")
+    parameter_name,
+    JAGS_to_monitor(prior_variable)
   )
 
   return(monitor)
 }
+.JAGS_monitor.mixture        <- function(prior_list, parameter_name){
+
+  .check_prior_list(prior_list)
+  if(!is.prior.mixture(prior_list))
+    stop("improper prior provided")
+  check_char(parameter_name, "parameter_name")
+
+  if(inherits(prior_list, "prior.bias_mixture")){
+
+    # dispatch between publication bias prior mixture and a standard prior mixture
+    is_PET            <- sapply(prior_list, is.prior.PET)
+    is_PEESE          <- sapply(prior_list, is.prior.PEESE)
+    is_weightfunction <- sapply(prior_list, is.prior.weightfunction)
+    is_none           <- sapply(prior_list, is.prior.none)
+
+    monitor <- "bias_indicator"
+
+    # if any prior is bias related, the whole component must be dispatching publication bias
+    if(any(!(is_PET | is_PEESE | is_weightfunction | is_none)))
+      stop("Mixture of publication bias and standard priors is not supported.")
+
+    if(any(is_PET)){
+      if(sum(is_PET) > 1) stop("Only one PET style publication bias adjustment is allowed.")
+
+      monitor <- c(monitor, "PET")
+    }
+    if(any(is_PEESE)){
+      if(sum(is_PEESE) > 1) stop("Only one PEESE style publication bias adjustment is allowed.")
+
+      monitor <- c(monitor, "PEESE")
+    }
+    if(any(is_weightfunction)){
+
+      monitor <- c(monitor, "omega")
+    }
+
+  }else{
+
+    monitor <- c(paste0(parameter_name, "_indicator"), parameter_name)
+  }
+
+  return(monitor)
+}
 
 #' @title Check and list 'JAGS' fitting settings
 #'
